<?php

/**
 * @file
 * Provides admin form settongs for the module.
 */

/**
 * Module admin form.
 */
function _node_delete_redirect_admin_form() {
  $form = array();

  $options = array(
    0 => t('No'),
    1 => t('Yes'),
  );

  $form['custom_node_delete_redirect_check'] = array(
    '#type' => 'radios',
    '#title' => t('Enable Node Delete Redirect'),
    '#default_value' => variable_get('node_delete_redirect_enabled', ''),
    '#options' => $options,
    '#description' => t('When off, redirection rules will not apply.'),
    '#required' => TRUE,
  );

  $form['ndr_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Enable Redirect For Content Type'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
    '#states' => array(
      'visible' => array(
        ':input[name=custom_node_delete_redirect_check]' => array(
          'value' => 1,
        ),
      ),
    ),
  );

  $content_types = node_type_get_types();
  foreach ($content_types as $keys => $values) {
    $form['ndr_settings']['ctype_' . $keys] = array(
      '#type' => 'checkbox',
      '#title' => check_plain($values->name),
      '#default_value' => variable_get('node_delete_redirect_checked_' . $keys, 0),
    );

    $form['ndr_settings']['redirect_' . $keys . '_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Redirect URL settings'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#states' => array(
        'visible' => array(
          ':input[name=ctype_' . $keys . ']' => array(
            'checked' => TRUE,
          ),
        ),
      ),
    );

    $form['ndr_settings']['redirect_' . $keys . '_settings']['redirect_' . $keys] = array(
      '#type' => 'textfield',
      '#title' => t('Redirect URL'),
      '#default_value' => variable_get('node_delete_redirect_' . $keys, ''),
      '#description' => t('Example: node/123'),
      '#element_validate' => array('_node_delete_redirect_path_validate'),
      '#size' => 45,
      '#maxlength' => 128,
    );
  }
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Settings'),
    '#submit' => array('_node_delete_redirect_submit'),
  );

  return $form;
}

/**
 * Module form validate.
 */
function _node_delete_redirect_path_validate($element, &$form_state) {
  $ctype = $element['#name'];
  $ctype = preg_replace("/([a-zA-Z]+)_([a-zA-Z0-9]+)/", "$2", $ctype);
  if ($form_state['values']['ctype_' . $ctype]) {
    if (!trim($element['#value']) || !drupal_valid_path($element['#value'], TRUE)) {
      form_set_error($element['#name'], t("The path '@path' is either invalid or you do not have access to it.", array('@path' => $element['#value'])));
    }
  }
}

/**
 * Module settings form submit.
 */
function _node_delete_redirect_submit($form, &$form_state) {
  variable_set('node_delete_redirect_enabled', $form_state['values']['custom_node_delete_redirect_check']);
  $content_types = node_type_get_types();
  if (variable_get('node_delete_redirect_enabled') == 1) {
    foreach ($content_types as $keys => $values) {
      if (isset($form_state['values']['ctype_' . $keys]) && $form_state['values']['ctype_' . $keys]) {
        variable_set('node_delete_redirect_' . $keys, $form_state['values']['redirect_' . $keys]);
        variable_set('node_delete_redirect_checked_' . $keys, $form_state['values']['ctype_' . $keys]);
      }
      else {
        variable_del('node_delete_redirect_' . $keys);
        variable_del('node_delete_redirect_checked_' . $keys);
      }
    }
  }
  else {
    foreach ($content_types as $keys => $values) {
      variable_del('node_delete_redirect_' . $keys);
      variable_del('node_delete_redirect_checked_' . $keys);
    }
  }
  drupal_set_message(t('Configuration Saved.'));
}
